
:mod:`emir.dataproducts` --- Data products of the EMIR pipeline
===============================================================

.. module:: emir.dataproducts
   :synopsis:  Data products of the EMIR pipeline

.. class:: FrameDataProduct

   EMIR Frame Data Product

.. class:: SourcesCatalog

   Sources catalog

.. class:: MasterBias

   Master bias EMIR frame

.. class:: ChannelLevelStatistics

   Statistic in channels

.. class:: MasterDark

   Master dark EMIR frame

.. class:: MasterIntensityFlat

   Master flar EMIR frame

